#  SAP LeanIX Resources
In addition to product documentation, there are several other resources to help you to get the most out of SAP LeanIX.
The following table lists the resources offered by SAP LeanIX. It provides an overview of how to use these resources and the type of information you can expect to find.
Resource | Content Offered
---|---
[Documentation](https://help.sap.com/docs/leanix "https://help.sap.com/docs/leanix") | Documentation offers guidance on using SAP LeanIX products.
[SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") | SAP LeanIX Support enables customers to submit a ticket and seek help from the SAP LeanIX Support Team. Customers can raise feature requests, report bugs, and seek support on any issues they need help with.
[SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") | Customer portal for SAP customers, which is the central entry point for SAP support, alerts, metrics, and insights into your SAP product portfolio.
[SAP Learning![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fproducts%2Fbusiness-transformation-management%2Fleanix "https://learning.sap.com/products/business-transformation-management/leanix") | SAP Learning is a comprehensive digital platform that enables users to develop skills and earn certifications across SAP solutions. It offers a broad selection of courses, including those for SAP LeanIX, to help you build your expertise.
[Onboarding Resource Center![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Fproduct%2Fonboarding-resource-center%2Fleanix.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/en/product/onboarding-resource-center/leanix.html") | A collection of resources that you need to seamlessly onboard your team and kickstart projects on the path to go-live.
[Product Roadmap![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2F "https://roadmap.leanix.net/") | The SAP LeanIX Product Roadmap provides a structured visualization of the planned and released features. Here, you can vote for features that you'd like to be implemented in the application and submit your ideas for new features.
[Website download area![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload "https://www.leanix.net/en/download") | Wide range of learning materials in the formats of White Papers, Tools, Success Stories, Posters, Presentations, Videos, and Documents. Various topics related to enterprise architecture, such as agile management, application rationalization, loT architecture, and technology risk, are covered through the documentation.
[Product Updates![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fupdates.leanix.net%2F "https://updates.leanix.net/") | Latest updates and announcements for SAP LeanIX products.
[Blog![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fblog.leanix.net%2Fen "http://blog.leanix.net/en") | Fresh insights into the most up-to-date news on SAP LeanIX and the industry.
[SAP LeanIX Store![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fen "https://store.leanix.net/en") | SAP LeanIX Store serves as a platform that enables users to share their knowledge and contribute custom reports to an always-growing network of EA specialists. Experts for specific industries or use cases help the EA community and their enterprises to elevate their EA program through best practice Reports (first time access to be done via SAP LeanIX).
[SAP LeanIX Community![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.leanix.net%2F "https://community.leanix.net/") | It is a platform for the customers to build a community around the best practices and SAP LeanIX Product Usage.
[YouTube channel![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.youtube.com%2Fuser%2FleanIXnet "https://www.youtube.com/user/leanIXnet") | SAP LeanIX's YouTube channel offers recorded webinars and tutorials.
[Status page![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fstatus.leanix.net%2F "http://status.leanix.net/") | An overview of the operational status of Web Application Enterprise Architecture, Services, Add-Ons, and Integrations.


YesNo
Send
